"""Some useful adapters"""
from typing import Any


def id_lambda(value: Any):
    """
    A function used in dynamic class generation that abstracts away a constant return value (like in getName)
    """
    return lambda *args: value


def fix_case(target: str, base: str) -> str:
    """Returns the lower-case string target with the case of base"""
    ret = "".join(
        [
            target[i].upper() if base[i].isupper() else target[i]
            for i in range(len(target))
        ]
    )
    return "".join(
        [
            target[i].upper() if base[i].isupper() else target[i]
            for i in range(len(target))
        ]
    )

def strtobool(val):
    """Convert a string representation of truth to true (1) or false (0).

    True values are 'y', 'yes', 't', 'true', 'on', and '1'; false values
    are 'n', 'no', 'f', 'false', 'off', and '0'.  Raises ValueError if
    'val' is anything else.
    """
    val = val.lower()
    if val in ('y', 'yes', 't', 'true', 'on', '1'):
        return 1
    elif val in ('n', 'no', 'f', 'false', 'off', '0'):
        return 0
    else:
        raise ValueError("invalid truth value {!r}".format(val))

